/**
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Authors:
 * 2009-
 *      Oscar Koeroo <okoeroo@nikhef.nl>
 *      Mischa Sall\'e <msalle@nikhef.nl>
 *      NIKHEF Amsterdam, the Netherlands
 *
 *  2006-2009
 *      Gerben Venekamp <venekamp@nikhef.nl>
 *      NIKHEF Amsterdam, the Netherlands
 *
 */

/*!
 *  \file glexec_closefrom.h
 *
 *  Provides functionality for to close all file descriptors from a certain
 *  minimum.
 */

#ifndef _GLEXEC_CLOSEFROM_H

#include "glexec_config.h"

#ifdef HAVE_DIRENT_H
/* Need dirent for defined(dirfd) on MacOS */
# include <dirent.h>
#endif

/* NOTE: MacOS (certain version) have dirfd as macro */
#if (!defined(HAVE_CLOSEFROM)) && \
    ( HAVE_DIRFD || defined(dirfd) ) && \
    ( HAVE_PROC_PID || HAVE_DEV_FD )

#define _GLEXEC_CLOSEFROM_NEEDS_INIT	1
/*!
 * Opens the directory DIR to /proc/$$/fd or /dev/fd, can be used to work around
 * a old RedHat problem where opendir() gives a permission denied after a
 * userswitch.
 */
void glexec_init_closefrom(void);

/*!
 * Closes the directory DIR to /proc/$$/fd or /dev/fd, only needed on non-POSIX
 * platforms
 * \return 0 success, 1 failure
 */
int glexec_close_dirp(void);
#elif defined _GLEXEC_CLOSEFROM_NEEDS_INIT
#undef _GLEXEC_CLOSEFROM_NEEDS_INIT
#endif

/*!
 * Implements a usable form of the OpenSolaris like closefrom() function
 * \param lowfd first file descriptor to close
 * \return 0 success, 1 failure
 */
int glexec_closefrom(int lowfd);
#endif
