/**
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Authors:
 * 2009-
 *      Oscar Koeroo <okoeroo@nikhef.nl>
 *      Mischa Sall\'e <msalle@nikhef.nl>
 *      NIKHEF Amsterdam, the Netherlands
 *
 *  2006-2009
 *      Gerben Venekamp <venekamp@nikhef.nl>
 *      NIKHEF Amsterdam, the Netherlands
 *
 */

/*!
 *  \file glexec_epilog.h
 *
 *  Provides functionality for epilogue script
 */

#ifndef _GLEXEC_EPILOG_H
#define _GLEXEC_EPILOG_H

/* For glexec_account_t */
#include "glexec.h"

/************************************************************************/
/* DEFINES AND TYPES                                                    */
/************************************************************************/

#define GLEXEC_EPILOG_PATTERN "GLEXEC_EPILOG_"

/************************************************************************/
/* FUNCTIONS                                                            */
/************************************************************************/

/*!
 * Setup epilogue:
 * - whether it should run
 * - optional user/group 
 * - whether it's trusted
 * - environment variables
 * \param caller, target account information
 * \param argc, argv payload command
 */
void glexec_setup_epilog(glexec_account_t *caller, glexec_account_t *target,
			 int argc, char *argv[]);

/*!
 * Does last minute tests on child status, sets up remaining env variables
 * (depending on child status), tests again for trustedness, then forks and
 * waits for epilog
 */
void glexec_run_epilog(void);

/*!
 * returns whether epilogue is trusted or not.
 * \param epilog_filename filename of epilogue script, when NULL use value
 * specified in glexec.conf
 * \return 1 epilogue is trusted
 * \return 0 epilogue is untrusted or other error occurred
 */
int glexec_check_epilog_trusted(char *epilog_filename);
#endif
